==> aez-8.5.1-en-download.zip: aez-8.5.1-en/webhelp/aez-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database adabasencryptionforzos
//
//	Copyright (c) 2016-2021 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var adabasencryptionforzos = {
    baseurls: ["../"],
    varname: "adabasencryptionforzos",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "intro/intro.htm", title: "Introduction to Adabas Encryption",
              tree: [
                  { url: "intro/intro_encrbasics.htm", title: "Encryption Basics" },
                  { url: "intro/intro_ibm.htm", title: "IBM Z® Support for Encryption" },
                  { url: "intro/intro_adabencr.htm", title: "Adabas Encryption for z/OS" },
                  { url: "intro/intro_encrseq.htm", title: "Encryption of Sequential Datasets" },
                  { url: "intro/intro_encrcont.htm", title: "Encryption of Container Datasets" },
              ]
            },
            { url: "install/ig_overview.htm", title: "Installation",
              tree: [
                  { url: "install/ig_req.htm", title: "System Requirements" },
                  { url: "install/ig_tape.htm", title: "About the Installation Tape" },
                  { url: "install/ig_adaencr.htm", title: "Installing Adabas Encryption Software" },
              ]
            },
            { url: "operations/og_overview.htm", title: "Operations",
              tree: [
                  { url: "operations/og_adarun.htm", title: "ADARUN ENCRYPTION Parameter" },
                  { url: "operations/og_create.htm", title: "Creating a New, Encrypted Database" },
                  { url: "operations/og_duplicate.htm", title: "Creating an Encrypted Copy of an Existing Database" },
                  { url: "operations/og_migrate.htm", title: "Migrating to an Encrypted Database" },
                  { url: "operations/og_rotate.htm", title: "Rotating the Dataset Encryption Key(s)" },
                  { url: "operations/og_encrypt.htm", title: "Encrypting Only Parts of ASSO and DATA" },
                  { url: "operations/og_copy.htm", title: "Copying Database Container Datasets" },
                  { url: "operations/og_inspectaez.htm", title: "Inspecting the Encryption Parameters and Attributes" },
              ]
            },
            { url: "reference/ref_ref.htm", title: "Reference",
              tree: [
                  { url: "reference/ref_message.htm", title: "Messages and Codes" },
                  { url: "reference/ref_glossary.htm", title: "Glossary" },
              ]
            },
            { url: "general/print.htm", title: "Printing this Documentation" },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: adabasencryptionforzos });

==> aez-8.6.1-en-download.zip: aez-8.6.1-en/webhelp/aez-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database adabasencryptionforzos
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var adabasencryptionforzos = {
    baseurls: ["../"],
    varname: "adabasencryptionforzos",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "relnotes/rnover.htm", title: "Release Notes",
              tree: [
                  { url: "relnotes/rn_enhance.htm", title: "Adabas Encryption Enhancements" },
                  { url: "relnotes/rn_eom.htm", title: "End of Maintenance" },
                  { url: "relnotes/rn_info.htm", title: "Documentation and Other Online Information" },
              ]
            },
            { url: "intro/intro.htm", title: "Introduction to Adabas Encryption",
              tree: [
                  { url: "intro/intro_encrbasics.htm", title: "Encryption Basics" },
                  { url: "intro/intro_ibm.htm", title: "IBM Z® Support for Encryption" },
                  { url: "intro/intro_adabencr.htm", title: "Adabas Encryption for z/OS" },
                  { url: "intro/intro_encrseq.htm", title: "Encryption of Sequential Datasets" },
                  { url: "intro/intro_encrcont.htm", title: "Encryption of Container Datasets" },
              ]
            },
            { url: "install/ig_overview.htm", title: "Installation",
              tree: [
                  { url: "install/ig_req.htm", title: "System Requirements" },
                  { url: "install/ig_adaencr.htm", title: "Installing Adabas Encryption" },
              ]
            },
            { url: "operations/og_overview.htm", title: "Operations",
              tree: [
                  { url: "operations/og_adarun.htm", title: "ADARUN ENCRYPTION Parameter" },
                  { url: "operations/og_create.htm", title: "Creating a New, Encrypted Database" },
                  { url: "operations/og_duplicate.htm", title: "Creating an Encrypted Copy of an Existing Database" },
                  { url: "operations/og_migrate.htm", title: "Migrating to an Encrypted Database" },
                  { url: "operations/og_rotate.htm", title: "Rotating the Dataset Encryption Key(s)" },
                  { url: "operations/og_encrypt.htm", title: "Encrypting Only Parts of ASSO and DATA" },
                  { url: "operations/og_copy.htm", title: "Copying Database Container Datasets" },
                  { url: "operations/og_inspectaez.htm", title: "Inspecting the Encryption Parameters and Attributes" },
              ]
            },
            { url: "reference/ref_ref.htm", title: "Reference",
              tree: [
                  { url: "reference/ref_message.htm", title: "Messages and Codes" },
                  { url: "reference/ref_glossary.htm", title: "Glossary" },
              ]
            },
            { url: "general/print.htm", title: "Printing this Documentation" },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: adabasencryptionforzos });
